# A clean scriptable library for Vast.ai
 
 This project is not intended to replace the open-source [vast.ai library](https://github.com/vast-ai/vast-python) but rather to complement it for those who want to have an easy-to-use API to build their own projects.


# Installation instructions
 ### This project is under active development, and will soon be available on PyPi. If you can't wait, you can clone this repo and copy `vast_ai.py` to your local directory and start playing around with the code
